=========
Changelog
=========

0.1.3 (2017-04-04)

* Admin classes added for separation of privileges
* Models updated

0.1.2 (2017-04-03)
==================

* Added views, templates, and models for testing.
* Changed Bootstrap version from 3.3.1 to 2.3.1  and JQuery 3.1.1 to 2.1.1

0.1.1 (2017-02-21)
==================

* Alpha release on PyPI.

